@@ -37,7 +37,7 @@ opt_case = click.option(
     ),
     default="snake",
 )
-opt_cmd = click.argument("cmd", nargs=-1)
+opt_cmd = click.argument("cmd", nargs=-1, required=True)
 
 
 @click.group()
@@ -64,7 +64,7 @@ def main():
     "-o",
     type=Path,
     help="Directory in which to put the output files",
-    required=True,
+    default=Path(),
 )
 @click.option(
     "--help-flag",
